@@ -1,11 +1,15 @@
+"""Abstract base class for end-user applications with plant and unit management."""
+
 from abc import ABC, abstractmethod
 
 from gemini_framework.framework.boot_plant import setup
 
 
 class ApplicationAbstract(ABC):
-    """Abstract class fpr application"""
+    """Abstract base class for end-user applications."""
+
     def __init__(self):
+        """Initialize application abstract."""
         self.plant = None
         self.unit = None
 
@@ -14,33 +18,33 @@ class ApplicationAbstract(ABC):
         self.outputs = dict()
 
     def load_plant(self, project_path, plant_name):
-        """Function to load the plant"""
+        """Load plant configuration and initialize framework plant."""
         self.plant = setup(project_path, plant_name)
 
     def select_unit(self, unit_name):
-        """Function to select unit for calculation"""
+        """Select unit in the plant by name for calculations."""
         for unit in self.plant.units:
             if unit.name == unit_name:
                 self.unit = unit
 
     def set_input(self, inputs):
-        """Function to set the input"""
+        """Set the input."""
         self.inputs = inputs
 
     def get_input(self):
-        """Function to get the input"""
+        """Set application inputs."""
         return self.inputs
 
     def get_output(self):
-        """Function to get the output"""
+        """Return application outputs."""
         return self.outputs
 
     @abstractmethod
     def init_parameters(self, initial_parameters):
-        """Abstract function to initialize the model parameters"""
+        """Initialize application-specific parameters."""
         pass
 
     @abstractmethod
     def calculate(self):
-        """Abstract function to calculate the model"""
+        """Run application computation model."""
         pass
