@@ -1,3 +1,8 @@
+"""Interactive chat pop-up application using Azure OpenAI or local Ollama.
+
+Supports document ingestion into ChromaDB and retrieval-augmented generation.
+"""
+
 from gemini_application.application_abstract import ApplicationAbstract
 import os
 import time
@@ -10,7 +15,10 @@ import re
 
 
 class ChatPopup(ApplicationAbstract):
+    """Chat popup application for LLM interactions."""
+
     def __init__(self):
+        """Initialize chat popup application."""
         super().__init__()
 
         self.azure_openai = False
@@ -41,16 +49,18 @@ class ChatPopup(ApplicationAbstract):
         self.num_relevant_docs = None
 
     def init_parameters(self, parameters):
-        """Function to initialize parameters"""
+        """Initialize parameters."""
         for key, value in parameters.items():
             setattr(self, key, value)
 
         self.initialize_model()
 
     def calculate(self):
+        """Calculate chat popup functionality."""
         return "Output calculated"
 
     def initialize_model(self):
+        """Initialize the chat model."""
         # API key for accessing langchain model
         os.environ["LANGCHAIN_API_KEY"] = (
             self.langchain_api_key
@@ -86,9 +96,11 @@ class ChatPopup(ApplicationAbstract):
         )
 
     def delete_collection(self):
+        """Delete the collection."""
         self.chroma_client.delete_collection(name=self.collection_name)
 
     def update_data(self):
+        """Update data for the chat popup."""
         # Step 1: Fetch existing metadata from the collection
         tic = time.time()
         existing_sources = set()
@@ -147,6 +159,7 @@ class ChatPopup(ApplicationAbstract):
             print(f"Model: Delete data {missing_file}")
 
     def get_embedding(self, user_message: str):
+        """Get embedding for user message."""
         if self.azure_openai:
             embedding = self.azure_embedding_client.embed_query(user_message)
         else:
@@ -158,6 +171,7 @@ class ChatPopup(ApplicationAbstract):
         return embedding
 
     def get_response(self, prompt: str) -> str:
+        """Get response from the model."""
         if self.azure_openai:
             print("using azure open AI...")
             response = self.azure_openai_client.invoke(prompt)
@@ -174,6 +188,7 @@ class ChatPopup(ApplicationAbstract):
         return response_str
 
     def filter_context(self, context):
+        """Filter context for relevance."""
         # the function returns the documents with similarity > self.similarity_threshold
         filtered_docs = []
         filtered_metas = []
@@ -205,6 +220,7 @@ class ChatPopup(ApplicationAbstract):
         }
 
     def process_prompt(self, user_message):
+        """Process user prompt."""
         print("processing prompt...")
 
         # Get embedding of the user query
@@ -255,6 +271,7 @@ class ChatPopup(ApplicationAbstract):
         }
 
     def get_embedding_list(self, chunks: list[str]):
+        """Get embedding list for chunks."""
         if self.azure_openai:
             embeddings = self.azure_embedding_client.embed_documents(chunks)
         else:
@@ -268,6 +285,7 @@ class ChatPopup(ApplicationAbstract):
         return embeddings
 
     def readfiles(self, docs_dir, filenames=None):
+        """Read files from directory."""
         text_contents = {}
 
         # Use provided filenames or list all from directory
@@ -294,6 +312,7 @@ class ChatPopup(ApplicationAbstract):
         return text_contents
 
     def chunksplitter(self, text, chunk_size):
+        """Split text into chunks."""
         words = re.findall(r'\S+', text)
 
         chunks = []
