@@ -1,3 +1,5 @@
+"""PDF report generation for well performance analysis and monitoring data."""
+
 from gemini_application.application_abstract import ApplicationAbstract
 from gemini_application.injectionwell.injectionwell_monitoring import InjectionWellMonitoring
 from gemini_model.well.pressure_drop import DPDT
@@ -22,11 +24,13 @@ matplotlib.use('Agg')
 
 
 class ReportGenerator(ApplicationAbstract):
-    """Class for generating reports
-            The class retrieves data from the database and generates a report in pdf format
+    """Class for generating reports.
+
+    The class retrieves data from the database and generates a report in pdf format.
+    """
 
-            """
     def __init__(self):
+        """Initialize report generator."""
         super().__init__()
         self.plant_name = None
         self.project_path = None
@@ -49,7 +53,7 @@ class ReportGenerator(ApplicationAbstract):
         self.bottomhole_skin_dp = bottomhole_skin_dp()
 
     def init_parameters(self, **kwargs):
-        """Function to initialize parameters"""
+        """Initialize parameters."""
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -70,10 +74,12 @@ class ReportGenerator(ApplicationAbstract):
         )
 
     def calculate(self):
+        """Calculate report data."""
         # Class ReportGenerator does not require calculations
         pass
 
     def get_units(self, tagname):
+        """Get units for given tagname."""
         tag = tagname.lower()
         if "pressure" in tag:
             units = "[bar]"
@@ -92,6 +98,7 @@ class ReportGenerator(ApplicationAbstract):
         return units
 
     def get_data(self, tagname):
+        """Get data for given tagname."""
         result, time = self.plant.database.read_internal_database(
             self.unit.plant.name,
             self.unit.name,
@@ -103,11 +110,13 @@ class ReportGenerator(ApplicationAbstract):
         return result, time
 
     def initialize_pdf_object(self):
+        """Initialize PDF object."""
         self.pdf_buffer = io.BytesIO()
         self.pdf_object = PdfPages(self.pdf_buffer)
         return
 
     def add_title_page(self):
+        """Add title page to PDF."""
         title = f'{self.project_name} Report'
         date_str = datetime.now().strftime("%A, %B %dth %Y, %I:%M %p")
         author = self.author_name
@@ -143,6 +152,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def get_injection_wells(self):
+        """Get injection wells data."""
         output = list()
         for unit in self.plant.units:
             unit_name = unit.name
@@ -151,6 +161,7 @@ class ReportGenerator(ApplicationAbstract):
         return output
 
     def get_production_wells(self):
+        """Get production wells data."""
         output = list()
         for unit in self.plant.units:
             unit_name = unit.name
@@ -159,6 +170,7 @@ class ReportGenerator(ApplicationAbstract):
         return output
 
     def get_esps(self):
+        """Get ESP data."""
         output = list()
         for unit in self.plant.units:
             unit_name = unit.name
@@ -167,6 +179,7 @@ class ReportGenerator(ApplicationAbstract):
         return output
 
     def add_timeseries_plot_to_pdf(self, data, timestamps, xlabel, ylabel, title):
+        """Add timeseries plot to PDF."""
         plt.figure(figsize=(10, 5))
         dates = [datetime.fromisoformat(ts.replace("Z", "")) for ts in timestamps]
         plt.plot(timestamps, dates, linestyle="-", color="b", label="Time Series")
@@ -184,6 +197,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close()
 
     def add_X_Y_plot_to_pdf(self, x_data, y_data):
+        """Add X-Y plot to PDF."""
         plt.figure(figsize=(11.69, 8.27))
         plt.plot(x_data, y_data, marker="o", linestyle="-", color="r", label="X-Y Plot")
         plt.xlabel("X Data")
@@ -195,6 +209,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close()
 
     def get_clean_list(self, value_list):
+        """Get clean list from value list."""
         clean_list = []
         for value in value_list:
             try:
@@ -207,6 +222,7 @@ class ReportGenerator(ApplicationAbstract):
         return clean_list
 
     def add_stats_plot(self, inj_wells, prod_wells):
+        """Add statistics plot to PDF."""
         inj_well_tagnames = [
             'injectionwell_flow.measured',
             'injectionwell_wellhead_pressure.measured',
@@ -304,6 +320,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def gather_stats(self, well_names, tagnames):
+        """Gather statistics for wells."""
         stats_data = []
         for well_name in well_names:
             self.select_unit(well_name)
@@ -340,6 +357,7 @@ class ReportGenerator(ApplicationAbstract):
         return stats_data
 
     def add_injection_report(self, inj_wells, tagnames):
+        """Add injection report to PDF."""
         num_wells = len(inj_wells)
         if num_wells == 0:
             return
@@ -430,6 +448,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def add_production_report(self, prod_wells, tagnames):
+        """Add production report to PDF."""
         num_wells = len(prod_wells)
         if num_wells == 0:
             return
@@ -519,6 +538,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def add_esp_report(self, esps, options):
+        """Add ESP report to PDF."""
         rcParams['figure.figsize'] = [11.69, 8.27]  # A4 landscape
         color_cycle = plt.cm.tab10.colors
         plots_per_page = 6  # 2 columns x 3 rows
@@ -620,6 +640,7 @@ class ReportGenerator(ApplicationAbstract):
                 plt.close(fig)
 
     def add_stats_table(self, inj_wells, prod_wells):
+        """Add statistics table to PDF."""
         all_stats_data = []
 
         # Tagnames for values to be added in the stats table
@@ -668,6 +689,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def add_cross_plot(self, units, tagnames, plot_type):
+        """Add cross plot to PDF."""
         num_units = len(units)
         if num_units == 0 or len(tagnames) < 3:
             print("Insufficient input: need at least one unit and three tagnames.")
@@ -760,6 +782,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def compute_skin_lines(self, inputs, flow_array, skin_array):
+        """Compute skin lines for plot."""
         well_name = inputs["well_name"]
         print(f'Computing skin lines for well: {well_name}')
 
@@ -811,6 +834,7 @@ class ReportGenerator(ApplicationAbstract):
         return results
 
     def convert_numeric_values(self, inputs):
+        """Convert numeric values in inputs."""
         for key, val in inputs.items():
             # Try to convert to float first
             try:
@@ -826,6 +850,7 @@ class ReportGenerator(ApplicationAbstract):
         return inputs
 
     def add_cross_plot_with_skin_lines(self, units, tagnames, inputs):
+        """Add cross plot with skin lines to PDF."""
         # Make sure numeric values are not in string format
         inputs = self.convert_numeric_values(inputs)
 
@@ -940,6 +965,7 @@ class ReportGenerator(ApplicationAbstract):
         plt.close(fig)
 
     def export_pdf(self):
+        """Export PDF report."""
         self.pdf_object.close()
         print("Plots exported to plots.pdf")
 
