@@ -1,3 +1,5 @@
+"""CO2 corrosion analysis application with caliper log processing and model optimization."""
+
 import os
 from datetime import datetime, timezone
 
@@ -18,9 +20,10 @@ tzobject = pytz.timezone('Europe/Amsterdam')
 
 
 class CO2CorrosionApplication(ApplicationAbstract):
-    """Class for CO2 Corrosion application"""
+    """Class for CO2 Corrosion application."""
 
     def __init__(self):
+        """Initialize CO2 corrosion application."""
         super().__init__()
         self.VLP = DPDT()
 
@@ -28,8 +31,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
         self.co2_models = []
 
     def init_parameters(self, corrosion_model_name='DLD'):
-
-        """Function to initialize models parameters"""
+        """Initialize models parameters."""
         # Init unit
         well_unit = self.unit
         # Get well tally
@@ -121,6 +123,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
             self.corrosion_models.append(corrosion_model)
 
     def get_caliper_logs(self):
+        """Get caliper logs data."""
         # Will hold caliper logs if any exist
         logs = {
             'logName': [],
@@ -150,6 +153,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
         self.inputs['uploadedLogs'] = logs
 
     def get_water_analysis_data(self):
+        """Get water analysis data."""
         # TODO: load water chemistry from UI
         project_folder = os.path.join(self.plant.project_path, self.plant.name)
 
@@ -163,7 +167,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
             pass
 
     def get_production_data(self):
-
+        """Get production data."""
         # Extract production data based on the well type
         if self.unit.parameters['type'] == 'production_well':
             # TODO: For production well, chenge to ESP
@@ -257,17 +261,18 @@ class CO2CorrosionApplication(ApplicationAbstract):
             self.inputs['monthly_dates'] = None
 
     def get_gas_analysis_data(self):
+        """Get gas analysis data."""
         pass
 
     def get_data(self):
-        """Loads data if available."""
+        """Load data if available."""
         self.get_caliper_logs()
         # TODO: to be updated
         # self.get_water_analysis_data()
         # self.get_production_data()
 
     def calculate(self):
-        """Main calculation pipeline."""
+        """Execute main calculation pipeline."""
         # print('Corrosion rate from logs started')
         self.get_corrosion_rate_from_logs()
         # print('Corrosion rate from models started')
@@ -276,6 +281,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
         self.predict_corrosion_rate()
 
     def add_corrosion_columns(self, df):
+        """Add corrosion columns to dataframe."""
         df['Max. Pen. [%]'] = None
         df['Max. Loss [%]'] = None
         df['Max. Pen. Depth [m]'] = None
@@ -287,6 +293,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
         return df
 
     def predict_corrosion_rate(self):
+        """Predict corrosion rate."""
         self.outputs['predictedCorrosionRate'] = pd.DataFrame(
             range(1, len(self.corrosion_models) + 1),
             index=range(len(self.corrosion_models)),
@@ -338,14 +345,13 @@ class CO2CorrosionApplication(ApplicationAbstract):
                 OD_nominal - (ID_nominal + predicted_corrosion_values / 25.4), 3)
 
     def get_corrosion_rate_from_logs(self):
+        """Compute measured corrosion based on log scenarios.
 
-        """
-        Compute measured corrosion based on the following scenarios:
+        Scenarios:
          - No logs => 'calculation not possible'
          - 1 log => compare that log to nominal ID as a baseline
          - 2+ logs => compare each log to the *previous* one (chronologically)
-       """
-
+        """
         # Create a DataFrame with Joint No. so we can store measured rates
         corrosion_rate = pd.DataFrame(range(1, len(self.corrosion_models) + 1),
                                       index=range(len(self.corrosion_models)),
@@ -437,12 +443,10 @@ class CO2CorrosionApplication(ApplicationAbstract):
         self.outputs['measuredCorrosionRate'] = corrosion_rate
 
     def process_caliper_logs(self):
+        """Build processed caliper logs for each log.
 
-        """
-        Builds 'processed_caliper_logs' for each log.
         If no logs, or only one, we'll handle in get_corrosion_rate_from_logs.
         """
-
         # Check well type
         if 'production' in self.unit.name:
             pass
@@ -489,9 +493,9 @@ class CO2CorrosionApplication(ApplicationAbstract):
 
                     # Calculate maximum circumferential wall loss
                     max_circ_wall_loss = (
-                            100 / 60 *
-                            ((caliper_subset ** 2 - base_id ** 2) /
-                             (base_od ** 2 - base_id ** 2)).sum(axis=1)
+                        100 / 60 *
+                        ((caliper_subset ** 2 - base_id ** 2) /
+                         (base_od ** 2 - base_id ** 2)).sum(axis=1)
                     ).mean()
 
                     # Remaining wall thickness
@@ -524,20 +528,20 @@ class CO2CorrosionApplication(ApplicationAbstract):
         # print("Log Processed successfully!")
 
     def get_corrosion_rate_from_models_segmented(self):
-        """
-        Computes modelled corrosion in multiple intervals:
-          - Nominal (baseline) date -> 1st log date
-          - 1st log date -> 2nd log date
-          - 2nd log date -> 3rd log date
-          ...
+        """Compute modelled corrosion in multiple intervals.
+
+        - Nominal (baseline) date -> 1st log date
+        - 1st log date -> 2nd log date
+        - 2nd log date -> 3rd log date
+        - etc.
 
         For each interval, we:
-          1) Filter the flow/pressure/temp data to [start_date, end_date)
-          2) Compute partial corrosion with a pairwise approach
-          3) Convert the sum of partial corrosion to [mm/year] over that interval
-          4) Store in a new column in `self.outputs['modelled_corrosion_rate']`
-        """
 
+        1. Filter the flow/pressure/temp data to [start_date, end_date)
+        2. Compute partial corrosion with a pairwise approach
+        3. Convert the sum of partial corrosion to [mm/year] over that interval
+        4. Store in a new column in ``self.outputs['modelledCorrosionRate']``
+        """
         # Check well type
         if self.unit.parameters['type'] == 'production_well':
             pass
@@ -591,7 +595,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
 
         # 4) For each pair of consecutive logs:
         for i in range(1, len(sorted_log_dates)):
-            start_date = sorted_log_dates[i-1]
+            start_date = sorted_log_dates[i - 1]
             end_date = sorted_log_dates[i]
             col_label = (f"Corrosion rate [mm/year] "
                          f"({start_date.strftime('%Y-%m-%d')} -> "
@@ -601,9 +605,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
 
     def _compute_corrosion_for_interval(self, start_date, end_date, column_label,
                                         output_switch='rate'):
-        """
-        Compute the corrosion rate for a specific interval.
-        """
+        """Compute the corrosion rate for a specific interval."""
         # Check well type
         try:
             well_type = self.unit.parameters['type']
@@ -751,9 +753,7 @@ class CO2CorrosionApplication(ApplicationAbstract):
 
     def coarsen_timeseries_by_change_point(self, df1, df2, df3, value_col='value',
                                            pen=3, plot=False):
-        """
-        Coarsen a time series by detecting segments where the values do not
-        change much.
+        """Coarsen a time series by detecting segments where the values do not change much.
 
         Parameters:
           df (pd.DataFrame): DataFrame with a DateTime index.
