@@ -1,3 +1,5 @@
+"""CO2 corrosion model parameter optimization using SciPy minimize."""
+
 import numpy as np
 import pandas as pd
 from scipy.optimize import minimize
@@ -9,15 +11,13 @@ from matplotlib import pyplot as plt
 
 
 class OptCO2Corrosion:
-    """
-    A class for calibrating (optimizing) CO2 Corrosion Model parameters
-    against measured data using SciPy's minimize function.
+    """Calibrate CO2 Corrosion Model parameters against measured data.
+
+    Uses SciPy's minimize function for optimization.
     """
 
     def __init__(self, inputs, outputs, VLP, unit, co2_models, joint_corrosion_models_opt):
-        """
-        """
-
+        """Initialize CO2 corrosion optimization model."""
         # Store references
         self.inputs = inputs
         self.outputs = outputs
@@ -76,9 +76,7 @@ class OptCO2Corrosion:
     # Normalization / Denormalization
     # ----------------------------------------------------------------------------------------------
     def normalize_params(self, real_params):
-        """
-        Convert real-valued parameters -> normalized [0,1]
-        """
+        """Convert real-valued parameters to normalized [0,1]."""
         norm_params = []
         for x, (lo, hi) in zip(real_params, self.real_bounds):
             z = (x - lo) / (hi - lo)
@@ -86,9 +84,7 @@ class OptCO2Corrosion:
         return np.array(norm_params)
 
     def denormalize_params(self, norm_params):
-        """
-        Convert normalized parameters [0,1] -> real-valued
-        """
+        """Convert normalized parameters [0,1] to real-valued."""
         real_params = []
         for z, (lo, hi) in zip(norm_params, self.real_bounds):
             x = lo + z * (hi - lo)
@@ -100,20 +96,20 @@ class OptCO2Corrosion:
     # -------------------------------------------------------------------------
 
     def get_corrosion_rate_from_models_segmented(self, calibrated_interval, init_run=False):
-        """
-        Computes modelled corrosion in multiple intervals:
-          - Nominal (baseline) date -> 1st log date
-          - 1st log date -> 2nd log date
-          - 2nd log date -> 3rd log date
-          ...
+        """Compute modelled corrosion in multiple intervals.
+
+        - Nominal (baseline) date -> 1st log date
+        - 1st log date -> 2nd log date
+        - 2nd log date -> 3rd log date
+        - ...
 
         For each interval, we:
-          1) Filter the flow/pressure/temp data to [start_date, end_date)
-          2) Compute partial corrosion with a pairwise approach
-          3) Convert the sum of partial corrosion to [mm/year] over that interval
-          4) Store in a new column in `self.outputs['modelled_corrosion_rate']`
-        """
 
+        1) Filter the flow/pressure/temp data to [start_date, end_date)
+        2) Compute partial corrosion with a pairwise approach
+        3) Convert the sum of partial corrosion to [mm/year] over that interval
+        4) Store in a new column in `self.outputs['modelled_corrosion_rate']`
+        """
         # Check well type
 
         # We'll store multiple columns, one per interval
@@ -175,12 +171,11 @@ class OptCO2Corrosion:
 
     def _compute_corrosion_for_interval(self, start_date, end_date, column_label, init_run,
                                         output_switch='rate'):
-        """
-        Helper method that filters the flow/pressure/temp data to [start_date, end_date),
-        does partial pairwise calculation, and then stores the result in
-        `self.outputs['modelled_corrosion_rate'][column_label]`.
-        """
+        """Filter flow/pressure/temp data and compute partial pairwise calculation.
 
+        Filters data to [start_date, end_date), does partial pairwise
+        calculation, and stores result in modelled_corrosion_rate.
+        """
         # Check well type
         well_type = 'productionwell'  # Default to production well
         if 'production' in self.unit.name:
@@ -306,9 +301,10 @@ class OptCO2Corrosion:
 
     def _compute_single_reading_corrosion(self, flow_row, press_row, temp_row,
                                           start_date, end_date, column_label):
-        """
-        If only one data point in interval => assume (end_date - start_date) for duration
-        and do a single partial calculation.
+        """Calculate single partial calculation for single data point interval.
+
+        If only one data point in interval, assume (end_date - start_date)
+        for duration and do a single partial calculation.
         """
         n_joints = len(self.inputs['tally']['Joint No.'])
         partial_corrosion = np.zeros(n_joints)
@@ -433,7 +429,8 @@ class OptCO2Corrosion:
         return sse
 
     def get_constraints(self):
-        """
+        """Define constraints for optimization.
+
         Example method to define constraints for optimization.
         Returns None if not used.
         """
@@ -443,12 +440,12 @@ class OptCO2Corrosion:
     # 5) Primary calibration routine: normalizes init guess & uses normalized bounds
     # ----------------------------------------------------------------------------------------------
     def calibrate_slsqp(self):
-        """
-        Calibrate (optimize) parameters for all models at once,
-        in normalized [0..1] space. Then denormalize the final solution,
-        push it back to the model, and show final measured vs. modeled rates.
-        """
+        """Calibrate parameters for all models in normalized space.
 
+        Optimize parameters for all models at once, in normalized [0..1]
+        space. Then denormalize the final solution, push it back to the
+        model, and show final measured vs. modeled rates.
+        """
         x0_real = self.xo_real
 
         # Normalize the initial guess so each param is in [0,1]
@@ -494,12 +491,12 @@ class OptCO2Corrosion:
         return result
 
     def calibrate_cobyla(self):
-        """
-        Calibrate (optimize) parameters for all models at once,
-        in normalized [0..1] space. Then denormalize the final solution,
-        push it back to the model, and show final measured vs. modeled rates.
-        """
+        """Calibrate parameters for all models in normalized space.
 
+        Optimize parameters for all models at once, in normalized [0..1]
+        space. Then denormalize the final solution, push it back to the
+        model, and show final measured vs. modeled rates.
+        """
         # Build a random initial guess in real space
         # x0_real = []
         # for (lo, hi) in self.real_bounds:
@@ -568,9 +565,7 @@ class OptCO2Corrosion:
 
     def coarsen_timeseries_by_change_point(self, df1, df2, df3, value_col='value',
                                            pen=3, plot=False):
-        """
-        Coarsen a time series by detecting segments where the values do not
-        change much.
+        """Coarsen a time series by detecting segments where the values do not change much.
 
         Parameters:
           df (pd.DataFrame): DataFrame with a DateTime index.
@@ -630,6 +625,7 @@ class OptCO2Corrosion:
     #     return opt.x * self.get_norms()
 
     def plot(self):
+        """Plot optimization results."""
         plt.figure()
         x = self.outputs['modelledCorrosionRate']['Joint No.'].values
 
